PCB Environment: LayoutArea Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
LayoutArea Class Reference

## Public Member Functions
const Vector_2 & | size () const
Real | area () const
const Bbox_2 & | bbox () const
Point_2 | origin () const
Real | aspectRatio () const
Real | diagonalLength () const
bool | isInside (const Point_25 &) const
bool | isBboxInside (const Object &) const
void | setOrigin (const Point_2 &v0)
void | setSize (const Vector_2 &size)
void | setMaxLayer (uint z)
void | setBox (const Bbox_2 &)
void | setRect (const Point_2 &min, const Point_2 &max)
void | setPolygonBbox (const Polygon_2 &)
void | expand (const Bbox_2 &box)

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/LayoutArea.hpp